#!/usr/bin/env python3
#
# 
# A quickly hacked together "proof of search"
#
#
from flask import Flask, request, send_from_directory, send_file
import os
import sys
import time


sys.path.append(os.path.join(os.path.dirname(__file__), '../lib'))

import config
import storage
import dosearch

app = Flask(__name__)

LAST_INDEX_CHECK = time.time()

@app.route("/search/", methods=['POST'])
def search():
    
    global LAST_INDEX_CHECK
    
    # Check that the index is up to date
    # and refresh if not
    if time.time() - LAST_INDEX_CHECK > 300:
        LAST_INDEX_CHECK = time.time()
        # Check the index
        if not storage.getIsIndexFresh():
            storage.loadIndex()
    
    j = request.get_json(force=True)
    
    srchterm = j['term'].lower()
    
    
    search_type = "ALL"
    if "type" in j:
        search_type = j['type']
    
    limit = False
    if "limit" in j:
        limit = int(j["limit"])
    
    return dosearch.search(srchterm, search_type, limit)


@app.route("/thumbs/<path:path>", methods=["GET"])
def thumbnail(path):
    return send_from_directory(f"{DB_PATH}/thumbs/", path)


@app.route("/static/<path:path>", methods=["GET"])
def staticassets(path):
    return send_from_directory(f"static/", path)

@app.route("/", methods=["GET"])
def index():
    return send_file(f"index.html")
    

if __name__ == "__main__":
    DB_PATH = config.getDBPath()
    dosearch.init(DB_PATH)
    app.run(debug=True, host="0.0.0.0", port=5000)

