#!/usr/bin/env python3
#
# Validate URLs from the index and remove anything that's no longer valid
#

import os
import random
import sys

sys.path.append(os.path.join(os.path.dirname(__file__), '../lib'))
sys.path.append(os.path.join(os.path.dirname(__file__), '../crawler/app'))

import crawler
import config
import storage



def selectURLS(num):
    ''' Pick a random selection of URLs out of the index
    '''
    
    result = []
    for s in random.sample(storage.INDEXES["ALL"], num):
        result.append(s['u'])
        
    return result
        

def validateURL(url):
    ''' Trigger a crawl to verify that the URL is still valid
    '''
    return crawler.crawlPage(url, override = False, ele = False)
    

if __name__ == "__main__":
    DB_PATH = config.getDBPath()
    storage.DB_PATH = DB_PATH
    
    # We want the ALL index enabled
    storage.INDEX_ALL = True
    
    # Load the index
    storage.loadIndex()
    
    urls = selectURLS(config.getRevalidateCount())
    for url in urls:
        if not validateURL(url):
            print(f"No longer valid: {url}")
    
    storage.indexStorage()
